@@ -130,12 +130,12 @@
 ##' @export
 getRateThroughTimeMatrix <- function(ephy, start.time=NULL, end.time=NULL, nslices=100, node=NULL, nodetype = 'include') {
 	
-	if (!'bammdata' %in% class(ephy)) {
+	if (!inherits(ephy, 'bammdata')) {
 		stop("Object ephy must be of class 'bammdata'\n");
 	}
 	
 	if (is.null(node)) {
-		nodeset <- c(length(ephy$tip.label)+1, ephy$edge[,2]);
+		nodeset <- c(length(ephy$tip.label) + 1, ephy$edge[,2]);
 	} else if (!is.null(node) & nodetype == 'include') {
 		nodeset <- unlist(sapply(node, function(x) getDesc(ephy, x)$desc_set))
 	} else if (!is.null(node) & nodetype == 'exclude') {
